==> polyapi-5.6.17.0.tar.gz: polyapi-5.6.17.0/polyapi/graph/types/point_series.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
Реализация графика типа "Серии точек".
"""

from ..base_graph import BaseGraph

class PointSeries(BaseGraph):
    """
    Реализация графика типа "Серии точек".
    """
    def __init__(self, base_bl: 'BusinessLogic', settings: str, grid: str, labels: dict,
                other: dict, common_params: dict, plot_type: str):
        super().__init__(base_bl, settings, grid, labels, other, common_params, plot_type, -1)

    def _get_settings(self) -> dict:
        """
        Получение актуальных настроек по заданному битмапу.
        :return: {
            'title_show': <value>,
            'legend': <value>,
            'axis': <value>,
            'axis_notes': <value>,
            'vertical_right_axix': <value>
        }
        """
        return self.get_actual_settings(['title_show', 'legend', 'axis', 'axis_notes', 'vertical_right_axix'])

    def _get_labels_settings(self) -> dict:
        """
        Получение настроек графика по параметру labels.
        :return: {'OX': <value>, 'OY': <value>}.
        """
        values_dict = {'OX': self.labels.get('OX', 10), 'OY': self.labels.get('OY', 10)}
        self.check_frequency_axis_5_30_5(values_dict)
        return values_dict

    def _get_other_settings(self) -> dict:
        """
        Получение прочих настроек графика.
        :return: {'diameter': <value>, 'show_trend_line': <value>, 'default_color': <value>}.
        """
        diameter, show_trend_line = self.other.get('diameter', 6.5), self.other.get('show_trend_line', True)
        if not self.check_bool(show_trend_line):
            raise ValueError('Param "show_trend_line" must be bool type!')
        self.check_interval_with_step('diameter', diameter, (1, 20), 0.5)
        return {"diameter": diameter, "show_trend_line": show_trend_line, "default_color": self.default_color}

    def draw(self):
        """
        Отрисовка графика. Состоит из нескольких этапов:
        1. Проверка данных для текущего типа графика;
        2. Формирование конфигурации графика;
        3. Вызов команды, отрисовывающей график.
        """
        # проверка данных и получение всех настроек
        self.check_olap_configuration(2, 0, 2, True)
        settings = self._get_settings()
        labels_settings = self._get_labels_settings()
        other_settings = self._get_other_settings()

        # получение базовых настроек и их дополнение на основе заданных пользователем значений
        graph_config = self.get_graph_config().copy()
        base_setting = {
            "titleShow": settings.get('title_show'),
            "legend": settings.get('legend'),
            "axis": settings.get('axis'),
            "axisNotes": settings.get('axis_notes'),
            "axisPosition": settings.get('vertical_right_axix'),
            "wireShow": self.grid,
            "axisNotesPeriodX": labels_settings.get('OX'),
            "axisNotesPeriodY": labels_settings.get('OY')
        }
        bubble_setting = {
            "defSize": other_settings.get('diameter'),
            "trendLine": other_settings.get('show_trend_line'),
            "defaultColor": other_settings.get('default_color')
        }
        graph_config['plotData'][self.graph_type]['config'].update({
            'base': base_setting,
            'bubbleBase': bubble_setting
        })

        # и, наконец, сохраняя настройки, отрисовываем сам график
        self.save_graph_settings(graph_config)

==> polyapi-5.6.18.0.tar.gz: polyapi-5.6.18.0/polyapi/graph/types/point_series.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
Реализация графика типа "Серии точек".
"""

from ..base_graph import BaseGraph

class PointSeries(BaseGraph):
    """
    Реализация графика типа "Серии точек".
    """
    def __init__(self, base_bl: 'BusinessLogic', settings: str, grid: str, labels: dict,
                other: dict, common_params: dict, plot_type: str):
        super().__init__(base_bl, settings, grid, labels, other, common_params, plot_type, -1)

    def _get_settings(self) -> dict:
        """
        Получение актуальных настроек по заданному битмапу.
        :return: {
            'title_show': <value>,
            'legend': <value>,
            'axis': <value>,
            'axis_notes': <value>,
            'vertical_right_axix': <value>
        }
        """
        return self.get_actual_settings(['title_show', 'legend', 'axis', 'axis_notes', 'vertical_right_axix'])

    def _get_labels_settings(self) -> dict:
        """
        Получение настроек графика по параметру labels.
        :return: {'OX': <value>, 'OY': <value>}.
        """
        values_dict = {'OX': self.labels.get('OX', 10), 'OY': self.labels.get('OY', 10)}
        self.check_frequency_axis_5_30_5(values_dict)
        return values_dict

    def _get_other_settings(self) -> dict:
        """
        Получение прочих настроек графика.
        :return: {'diameter': <value>, 'show_trend_line': <value>, 'default_color': <value>}.
        """
        diameter, show_trend_line = self.other.get('diameter', 6.5), self.other.get('show_trend_line', True)
        if not self.check_bool(show_trend_line):
            raise ValueError('Param "show_trend_line" must be bool type!')
        self.check_interval_with_step('diameter', diameter, (1, 20), 0.5)
        return {"diameter": diameter, "show_trend_line": show_trend_line, "default_color": self.default_color}

    def draw(self):
        """
        Отрисовка графика. Состоит из нескольких этапов:
        1. Проверка данных для текущего типа графика;
        2. Формирование конфигурации графика;
        3. Вызов команды, отрисовывающей график.
        """
        # проверка данных и получение всех настроек
        self.check_olap_configuration(2, 0, 2, True)
        settings = self._get_settings()
        labels_settings = self.get_labels_settings("two_axis", add_short_format=False)
        other_settings = self._get_other_settings()

        # получение базовых настроек и их дополнение на основе заданных пользователем значений
        graph_config = self.get_graph_config().copy()
        base_setting = {
            "titleShow": settings.get('title_show'),
            "legend": settings.get('legend'),
            "axis": settings.get('axis'),
            "axisNotes": settings.get('axis_notes'),
            "axisPosition": settings.get('vertical_right_axix'),
            "wireShow": self.grid
        }
        base_setting.update(labels_settings)
        bubble_setting = {
            "defSize": other_settings.get('diameter'),
            "trendLine": other_settings.get('show_trend_line'),
            "defaultColor": other_settings.get('default_color')
        }
        graph_config['plotData'][self.graph_type]['config'].update({
            'base': base_setting,
            'bubbleBase': bubble_setting
        })

        # и, наконец, сохраняя настройки, отрисовываем сам график
        self.save_graph_settings(graph_config)
